.. |arxiv_badge| image:: https://img.shields.io/badge/arXiv-2501.16095-blue?logo=arxiv
   :target: https://arxiv.org/abs/2501.16095
   :alt: arXiv paper
   :class: inline-badge
   
.. |System| replace:: :class:`~MoleCool.System.System`

.. |Levelsystem| replace:: :class:`~MoleCool.Levelsystem.Levelsystem`

.. |ElectronicState| replace:: :class:`~MoleCool.Levelsystem.ElectronicState`

.. |State| replace:: :class:`~MoleCool.Levelsystem.State`

.. |Lasersystem| replace:: :class:`~MoleCool.Lasersystem.Lasersystem`

.. |Laser| replace:: :class:`~MoleCool.Lasersystem.Laser`

.. |Bfield| replace:: :class:`~MoleCool.Bfield.Bfield`

.. |spectra| replace:: :mod:`~MoleCool.spectra`